@@ -3,14 +3,14 @@ context("utils")
 test_that("units_per_unit", {
   expect_identical(dtt_units_per_unit(), 86400)
   expect_identical(dtt_units_per_unit("hours"), 24)
-  expect_identical(dtt_units_per_unit("minutes", "seconds"), 1/60)
+  expect_identical(dtt_units_per_unit("minutes", "seconds"), 1 / 60)
   expect_equal(dtt_units_per_unit("days", "months"), 30.41667, tolerance = 1e-06)
 })
 
 test_that("adjust_units", {
   expect_identical(dtt_adjust_units(1), 1)
   expect_identical(dtt_adjust_units(1, "minutes"), 60)
-  expect_identical(dtt_adjust_units(1, to = "minutes"), 1/60)
+  expect_identical(dtt_adjust_units(1, to = "minutes"), 1 / 60)
 })
 
 test_that("NA", {
@@ -30,5 +30,5 @@ test_that("c.POSIXct", {
 })
 
 test_that("c.hms", {
-  expect_identical(c(hms::as.hms("00:00:00")), hms::as.hms("00:00:00"))
+  expect_identical(c(hms::as_hms("00:00:00")), hms::as_hms("00:00:00"))
 })
